@@ -18,16 +18,19 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from collections.abc import Mapping
 from typing import Any, Optional
+from functools import reduce
 
 from .data_model import E_NO_DATA_MODEL_FOUND, DataModel
 from .exceptions import PantherError
 from .immutable import ImmutableCaseInsensitiveDict, json_encoder
 
+__all__ = ["PantherEvent"]
+
 
 class PantherEvent(ImmutableCaseInsensitiveDict):  # pylint: disable=R0901
     """Panther enriched event with unified data model (udm) access."""
 
-    def __init__(self, event: Mapping, data_model: Optional[DataModel]):
+    def __init__(self, event: Mapping, data_model: Optional[DataModel] = None):
         """Create data model lookups
 
         Args:
@@ -63,6 +66,14 @@ class PantherEvent(ImmutableCaseInsensitiveDict):  # pylint: disable=R0901
         # no matches, return None by default
         return None
 
+    def deep_get(self, *keys: str, default: Any = None) -> Any:
+        """Safely return the value of an arbitrarily nested map"""
+        return reduce(
+            lambda d, key: d.get(key, default) if isinstance(d, Mapping) else default,
+            keys,
+            self,
+        )
+
     def _validate(self) -> None:
         if not self.data_model:
             raise PantherError(E_NO_DATA_MODEL_FOUND, self._container.get("p_log_type"))
